@@ -22,7 +22,7 @@
 #include <string>
 
 #include "dialogs.h"
-#include "ICbase.h"
+#include "rigs.h"
 #include "trace.h"
 #include "xml_server.h"
 
@@ -44,8 +44,10 @@ Fl_Group *tabXCVR = (Fl_Group *)0;
 	Fl_Check_Button *btnrtsptt = (Fl_Check_Button *)0;
 	Fl_Check_Button *btndtrptt = (Fl_Check_Button *)0;
 	Fl_Check_Button *chkrtscts = (Fl_Check_Button *)0;
-	Fl_Check_Button *btnrtsplus = (Fl_Check_Button *)0;
-	Fl_Check_Button *btndtrplus = (Fl_Check_Button *)0;
+	Fl_Check_Button *btnrtsplus1 = (Fl_Check_Button *)0;
+	Fl_Check_Button *btndtrplus1 = (Fl_Check_Button *)0;
+	Fl_Check_Button *btnrtsplus2 = (Fl_Check_Button *)0;
+	Fl_Check_Button *btndtrplus2 = (Fl_Check_Button *)0;
 	//Fl_Check_Button *btn_notxqsy = (Fl_Check_Button *)0;
 	Fl_Int_Input *txtCIV = (Fl_Int_Input *)0;
 	Fl_Button *btnCIVdefault = (Fl_Button *)0;
@@ -83,38 +85,39 @@ Fl_Group *tabSERVER = (Fl_Group *)0;
 	Fl_Box *box_fldigi_connect = (Fl_Box *)0;
 
 Fl_Group *tabPOLLING = (Fl_Group *)0;
-	Fl_Value_Input *poll_smeter = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_pout = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_swr = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_alc = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_frequency = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_mode = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_bandwidth = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_volume = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_micgain = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_rfgain = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_power_control = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_ifshift = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_notch = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_auto_notch = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_pre_att = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_squelch = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_split = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_noise = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_nr = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_compression = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_tuner = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_ptt = (Fl_Value_Input *)0;
-	Fl_Value_Input *poll_break_in = (Fl_Value_Input *)0;
+	Fl_Check_Button *poll_smeter = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_pout = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_swr = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_alc = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_frequency = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_mode = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_bandwidth = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_volume = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_micgain = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_rfgain = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_power_control = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_ifshift = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_notch = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_auto_notch = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_pre_att = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_squelch = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_split = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_noise = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_nr = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_compression = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_tuner = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_ptt = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_break_in = (Fl_Check_Button *)0;
 	Fl_Button *btnClearAddControls = (Fl_Button *)0;
 
-	Fl_Value_Input *poll_meters = (Fl_Value_Input *)0;
 	Fl_Button *btnSetMeters = (Fl_Button *)0;
-	Fl_Value_Input *poll_ops = (Fl_Value_Input *)0;
 	Fl_Button *btnSetOps = (Fl_Button *)0;
-	Fl_Value_Input *poll_all = (Fl_Value_Input *)0;
 	Fl_Button *btnSetAdd = (Fl_Button *)0;
 
+	Fl_Check_Button *poll_meters = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_ops = (Fl_Check_Button *)0;
+	Fl_Check_Button *poll_all = (Fl_Check_Button *)0;
+
 Fl_Group *tabSNDCMD = (Fl_Group *)0;
 	Fl_Input2 *txt_command = (Fl_Input2 *)0;
 	Fl_Button *btn_icom_pre = (Fl_Button *)0;
@@ -138,6 +141,7 @@ Fl_Group *tabTRACE = (Fl_Group *)0;
 	Fl_Check_Button *btn_settrace = (Fl_Check_Button *)0;
 	Fl_Check_Button *btn_debugtrace = (Fl_Check_Button *)0;
 	Fl_Check_Button *btn_rpctrace = (Fl_Check_Button *)0;
+	Fl_Check_Button *btn_serialtrace = (Fl_Check_Button *)0;
 	Fl_Check_Button *btn_start_stop_trace = (Fl_Check_Button *)0;
 	Fl_ComboBox *selectlevel = (Fl_ComboBox *)0;
 	Fl_Button *btn_viewtrace = (Fl_Button *)0;
@@ -289,6 +293,10 @@ static void cb_btn_rpctrace(Fl_Check_Button *, void *) {
 	progStatus.rpctrace = btn_rpctrace->value();
 }
 
+static void cb_btn_serialtrace(Fl_Check_Button *, void *) {
+	progStatus.serialtrace = btn_serialtrace->value();
+}
+
 static void cb_btn_start_stop_trace(Fl_Check_Button *, void *) {
 	progStatus.start_stop_trace = btn_start_stop_trace->value();
 }
@@ -299,6 +307,7 @@ static void cb_selectlevel(Fl_ComboBox *, void *) {
 }
 
 static void cb_btn_viewtrace(Fl_Button *, void *) {
+	if (!tracewindow) make_trace_window();
 	tracewindow->show();
 }
 
@@ -457,20 +466,28 @@ static void cb_chkrtscts(Fl_Check_Button*, void*) {
 	btn2_init_ser_port->redraw_label();
 }
 
-static void cb_btnrtsplus(Fl_Check_Button*, void*) {
+static void cb_btnrtsplus(Fl_Check_Button *b, void*) {
+	int val = b->value();
 	btn_init_ser_port->labelcolor(FL_RED);
 	btn_init_ser_port->redraw_label();
 
 	btn2_init_ser_port->labelcolor(FL_RED);
 	btn2_init_ser_port->redraw_label();
+
+	btnrtsplus1->value(val);
+	btnrtsplus2->value(val);
 }
 
-static void cb_btndtrplus(Fl_Check_Button*, void*) {
+static void cb_btndtrplus(Fl_Check_Button *b, void*) {
+	int val = b->value();
 	btn_init_ser_port->labelcolor(FL_RED);
 	btn_init_ser_port->redraw_label();
 
 	btn2_init_ser_port->labelcolor(FL_RED);
 	btn2_init_ser_port->redraw_label();
+
+	btndtrplus1->value(val);
+	btndtrplus2->value(val);
 }
 
 static void cb_txtCIV(Fl_Int_Input* o, void*) {
@@ -535,99 +552,99 @@ static void cb_server_port(Fl_Input2* o, void*) {
 	set_server_port(::xmlport);
 }
 
-static void cb_poll_smeter(Fl_Value_Input* o, void*) {
+static void cb_poll_smeter(Fl_Check_Button* o, void*) {
 	progStatus.poll_smeter = o->value();
 }
 
-static void cb_poll_pout(Fl_Value_Input* o, void*) {
+static void cb_poll_pout(Fl_Check_Button* o, void*) {
 	progStatus.poll_pout = o->value();
 }
 
-static void cb_poll_swr(Fl_Value_Input* o, void*) {
+static void cb_poll_swr(Fl_Check_Button* o, void*) {
 	progStatus.poll_swr = o->value();
 }
 
-static void cb_poll_alc(Fl_Value_Input* o, void*) {
+static void cb_poll_alc(Fl_Check_Button* o, void*) {
 	progStatus.poll_alc = o->value();
 }
 
-static void cb_poll_frequency(Fl_Value_Input* o, void*) {
+static void cb_poll_frequency(Fl_Check_Button* o, void*) {
 	progStatus.poll_frequency = o->value();
 }
 
-static void cb_poll_mode(Fl_Value_Input* o, void*) {
+static void cb_poll_mode(Fl_Check_Button* o, void*) {
 	progStatus.poll_mode = o->value();
 }
 
-static void cb_poll_bandwidth(Fl_Value_Input* o, void*) {
+static void cb_poll_bandwidth(Fl_Check_Button* o, void*) {
 	progStatus.poll_bandwidth = o->value();
 }
 
-static void cb_poll_volume(Fl_Value_Input* o, void*) {
+static void cb_poll_volume(Fl_Check_Button* o, void*) {
 	progStatus.poll_volume = o->value();
 }
 
-static void cb_poll_micgain(Fl_Value_Input* o, void*) {
+static void cb_poll_micgain(Fl_Check_Button* o, void*) {
 	progStatus.poll_micgain = o->value();
 }
 
-static void cb_poll_rfgain(Fl_Value_Input* o, void*) {
+static void cb_poll_rfgain(Fl_Check_Button* o, void*) {
 	progStatus.poll_rfgain = o->value();
 }
 
-static void cb_poll_power_control(Fl_Value_Input* o, void*) {
+static void cb_poll_power_control(Fl_Check_Button* o, void*) {
 	progStatus.poll_power_control = o->value();
 }
 
-static void cb_poll_ifshift(Fl_Value_Input* o, void*) {
+static void cb_poll_ifshift(Fl_Check_Button* o, void*) {
 	progStatus.poll_ifshift = o->value();
 }
 
-static void cb_poll_notch(Fl_Value_Input* o, void*) {
+static void cb_poll_notch(Fl_Check_Button* o, void*) {
 	progStatus.poll_notch = o->value();
 }
 
-static void cb_poll_auto_notch(Fl_Value_Input* o, void*) {
+static void cb_poll_auto_notch(Fl_Check_Button* o, void*) {
 	progStatus.poll_auto_notch = o->value();
 }
 
-static void cb_poll_pre_att(Fl_Value_Input* o, void*) {
+static void cb_poll_pre_att(Fl_Check_Button* o, void*) {
 	progStatus.poll_pre_att = o->value();
 }
 
-static void cb_poll_squelch(Fl_Value_Input* o, void*) {
+static void cb_poll_squelch(Fl_Check_Button* o, void*) {
 	progStatus.poll_squelch = o->value();
 }
 
-static void cb_poll_split(Fl_Value_Input* o, void*) {
+static void cb_poll_split(Fl_Check_Button* o, void*) {
 	progStatus.poll_split = o->value();
 }
 
-static void cb_poll_noise(Fl_Value_Input* o, void*) {
+static void cb_poll_noise(Fl_Check_Button* o, void*) {
 	progStatus.poll_noise = o->value();
 }
 
-static void cb_poll_nr(Fl_Value_Input* o, void*) {
+static void cb_poll_nr(Fl_Check_Button* o, void*) {
 	progStatus.poll_nr = o->value();
 }
 
-static void cb_poll_compression(Fl_Value_Input* o, void *) {
+static void cb_poll_compression(Fl_Check_Button* o, void *) {
 	progStatus.poll_compression = o->value();
 }
 
-static void cb_poll_tuner(Fl_Value_Input* o, void *) {
+static void cb_poll_tuner(Fl_Check_Button* o, void *) {
 	progStatus.poll_tuner = o->value();
 }
 
-static void cb_poll_meters(Fl_Value_Input* o, void*) {
+static void cb_poll_meters(Fl_Check_Button* o, void*) {
 	progStatus.poll_meters = o->value();
 }
 
-static void cb_poll_ptt(Fl_Value_Input* o, void*) {
+static void cb_poll_ptt(Fl_Check_Button* o, void*) {
 	progStatus.poll_ptt = o->value();
 }
 
-static void cb_poll_break_in(Fl_Value_Input* o, void*) {
+static void cb_poll_break_in(Fl_Check_Button* o, void*) {
 	progStatus.poll_break_in = o->value();
 }
 
@@ -643,7 +660,7 @@ static void cb_btnSetMeters(Fl_Button*, void*) {
 	progStatus.poll_alc = progStatus.poll_meters;
 }
 
-static void cb_poll_ops(Fl_Value_Input* o, void*) {
+static void cb_poll_ops(Fl_Check_Button* o, void*) {
 	progStatus.poll_ops = o->value();
 }
 
@@ -657,7 +674,7 @@ static void cb_btnSetOps(Fl_Button*, void*) {
 	progStatus.poll_bandwidth = progStatus.poll_ops;
 }
 
-static void cb_poll_all(Fl_Value_Input* o, void*) {
+static void cb_poll_all(Fl_Check_Button* o, void*) {
 	progStatus.poll_all = o->value();
 }
 
@@ -677,22 +694,25 @@ static void cb_btnSetAdd(Fl_Button*, void*) {
 	poll_compression->value(progStatus.poll_all);
 	poll_tuner->value(progStatus.poll_all);
 	poll_ptt->value(progStatus.poll_all);
+	poll_break_in->value(progStatus.poll_all);
 
-	progStatus.poll_volume = progStatus.poll_all;
-	progStatus.poll_micgain = progStatus.poll_all;
-	progStatus.poll_rfgain = progStatus.poll_all;
-	progStatus.poll_power_control = progStatus.poll_all;
-	progStatus.poll_ifshift = progStatus.poll_all;
-	progStatus.poll_notch = progStatus.poll_all;
-	progStatus.poll_auto_notch = progStatus.poll_all;
-	progStatus.poll_pre_att = progStatus.poll_all;
-	progStatus.poll_squelch = progStatus.poll_all;
-	progStatus.poll_split = progStatus.poll_all;
-	progStatus.poll_noise = progStatus.poll_all;
-	progStatus.poll_nr = progStatus.poll_all;
-	progStatus.poll_compression = progStatus.poll_all;
-	progStatus.poll_tuner = progStatus.poll_all;
-	progStatus.poll_ptt = progStatus.poll_all;
+	progStatus.poll_volume = 
+	progStatus.poll_micgain = 
+	progStatus.poll_rfgain = 
+	progStatus.poll_power_control = 
+	progStatus.poll_ifshift = 
+	progStatus.poll_notch = 
+	progStatus.poll_auto_notch = 
+	progStatus.poll_pre_att = 
+	progStatus.poll_squelch = 
+	progStatus.poll_split = 
+	progStatus.poll_noise = 
+	progStatus.poll_nr = 
+	progStatus.poll_compression = 
+	progStatus.poll_tuner = 
+	progStatus.poll_ptt = 
+	progStatus.poll_break_in = 
+		progStatus.poll_all;
 }
 
 static void cb_btn_send_command(Fl_Button *o, void*) {
@@ -821,8 +841,6 @@ static void cb_init_ser_port(Fl_Return_Button*, void*) {
 	if (progStatus.UIsize == wide_ui) {
 		btn_show_controls->label("@-22->");
 		btn_show_controls->redraw_label();
-		grpTABS->hide();
-		mainwindow->resizable(grpTABS);
 		mainwindow->size(mainwindow->w(), WIDE_MAINH);
 		mainwindow->size_range(WIDE_MAINW, WIDE_MAINH, 0, WIDE_MAINH);
 	}
@@ -852,8 +870,8 @@ static void cb_init_ser_port(Fl_Return_Button*, void*) {
 	progStatus.comm_catptt = btncatptt->value();
 	progStatus.comm_dtrptt = btndtrptt->value();
 	progStatus.comm_rtscts = chkrtscts->value();
-	progStatus.comm_rtsplus = btnrtsplus->value();
-	progStatus.comm_dtrplus = btndtrplus->value();
+	progStatus.comm_rtsplus = btnrtsplus1->value();
+	progStatus.comm_dtrplus = btndtrplus1->value();
 
 	progStatus.imode_B  = progStatus.imode_A  = selrig->def_mode;
 	progStatus.iBW_B    = progStatus.iBW_A    = selrig->def_bw;
@@ -1042,7 +1060,7 @@ Fl_Group *createXCVR(int X, int Y, int W, int H, const char *label)
 		btnTwoStopBit->value(progStatus.stopbits == 2);
 
 		btnRigCatEcho = new Fl_Check_Button(
-			btnOneStopBit->x(), btnOneStopBit->y() + 26,
+			btnOneStopBit->x(), btnOneStopBit->y() + 25,
 			22, 22, _("Echo "));
 		btnRigCatEcho->down_box(FL_DOWN_BOX);
 		btnRigCatEcho->callback((Fl_Callback*)cb_btnRigCatEcho);
@@ -1057,6 +1075,18 @@ Fl_Group *createXCVR(int X, int Y, int W, int H, const char *label)
 		chkrtscts->callback((Fl_Callback*)cb_chkrtscts);
 		chkrtscts->value(progStatus.comm_rtscts);
 
+		btnrtsplus1 = new Fl_Check_Button(
+			btnRigCatEcho->x(), btnRigCatEcho->y() + 25, 22, 22, _("RTS +12 v"));
+		btnrtsplus1->tooltip(_("Initial state of RTS"));
+		btnrtsplus1->callback((Fl_Callback*)cb_btnrtsplus);
+		btnrtsplus1->value(progStatus.comm_rtsplus);
+
+		btndtrplus1 = new Fl_Check_Button(
+			chkrtscts->x(), btnrtsplus1->y(), 22, 22, _("DTR +12 v"));
+		btndtrplus1->tooltip(_("Initial state of DTR"));
+		btndtrplus1->callback((Fl_Callback*)cb_btndtrplus);
+		btndtrplus1->value(progStatus.comm_dtrplus);
+
 		cntRigCatRetries = new Fl_Counter(
 			xcvr_grp1->x() + xcvr_grp1->w() - 110 - 4, mnuBaudrate->y(),
 			110, 22, _("Retries"));
@@ -1072,10 +1102,10 @@ Fl_Group *createXCVR(int X, int Y, int W, int H, const char *label)
 
 		cntRigCatTimeout = new Fl_Counter(
 			cntRigCatRetries->x(), btnOneStopBit->y(),
-			110, 22, _("Retry intvl"));
-		cntRigCatTimeout->tooltip(_("Time between retries is msec"));
-		cntRigCatTimeout->minimum(2);
-		cntRigCatTimeout->maximum(200);
+			110, 22, _("Timeout"));
+		cntRigCatTimeout->tooltip(_("Serial port select timeout"));
+		cntRigCatTimeout->minimum(0);
+		cntRigCatTimeout->maximum(100);
 		cntRigCatTimeout->step(1);
 		cntRigCatTimeout->value(10);
 		cntRigCatTimeout->callback((Fl_Callback*)cb_cntRigCatTimeout);
@@ -1086,7 +1116,7 @@ Fl_Group *createXCVR(int X, int Y, int W, int H, const char *label)
 		cntRigCatWait = new Fl_Counter(
 			cntRigCatRetries->x(), btnRigCatEcho->y(),
 			110, 22, _("Cmds"));
-		cntRigCatWait->tooltip(_("Wait millseconds between sequential commands"));
+		cntRigCatWait->tooltip(_("Wait millseconds between set/get commands"));
 		cntRigCatWait->minimum(0);
 		cntRigCatWait->maximum(100);
 		cntRigCatWait->step(1);
@@ -1216,12 +1246,17 @@ Fl_Group *createTRACE(int X, int Y, int W, int H, const char *label)
 	btn_rpctrace->callback((Fl_Callback*)cb_btn_rpctrace);
 	btn_rpctrace->tooltip(_("Enable trace of XmlRpc methods"));
 
-	btn_start_stop_trace = new Fl_Check_Button(X + 240, Y + 80, 80, 20, _("Trace start/stop code"));
+	btn_serialtrace = new Fl_Check_Button(X + 240, Y + 80, 80, 20, _("Trace serial code"));
+	btn_serialtrace->value(progStatus.serialtrace);
+	btn_serialtrace->callback((Fl_Callback*)cb_btn_serialtrace);
+	btn_serialtrace->tooltip(_("Enable trace of serial i/o"));
+
+	btn_start_stop_trace = new Fl_Check_Button(X + 240, Y + 110, 80, 20, _("Trace start/stop code"));
 	btn_start_stop_trace->value(progStatus.start_stop_trace);
 	btn_start_stop_trace->callback((Fl_Callback*)cb_btn_start_stop_trace);
 	btn_start_stop_trace->tooltip(_("Enable trace of start/stop operations"));
 
-	selectlevel = new Fl_ComboBox(X + 240, Y + 110, 80, 20, _("XmlRpc trace level"));
+	selectlevel = new Fl_ComboBox(X + 240, Y + 140, 80, 20, _("XmlRpc trace level"));
 	selectlevel->add("0|1|2|3|4");
 	selectlevel->align(FL_ALIGN_RIGHT);
 	selectlevel->index(progStatus.rpc_level);
@@ -1344,20 +1379,20 @@ Fl_Group *createPTT(int X, int Y, int W, int H, const char *label)
 		btndtrptt->callback((Fl_Callback*)cb_btndtrptt);
 		btndtrptt->value(progStatus.comm_dtrptt);
 
-		btnrtsplus = new Fl_Check_Button(
+		btnrtsplus2 = new Fl_Check_Button(
 			btnrtsptt->x(), btnrtsptt->y() + 24, 102, 21, _("RTS +12 v"));
-		btnrtsplus->tooltip(_("Initial state of RTS"));
-		btnrtsplus->callback((Fl_Callback*)cb_btnrtsplus);
-		btnrtsplus->value(progStatus.comm_rtsplus);
+		btnrtsplus2->tooltip(_("Initial state of RTS"));
+		btnrtsplus2->callback((Fl_Callback*)cb_btnrtsplus);
+		btnrtsplus2->value(progStatus.comm_rtsplus);
 
-		btndtrplus = new Fl_Check_Button(
+		btndtrplus2 = new Fl_Check_Button(
 			btndtrptt->x(), btndtrptt->y() + 24, 100, 21, _("DTR +12 v"));
-		btndtrplus->tooltip(_("Initial state of DTR"));
-		btndtrplus->callback((Fl_Callback*)cb_btndtrplus);
-		btndtrplus->value(progStatus.comm_dtrplus);
+		btndtrplus2->tooltip(_("Initial state of DTR"));
+		btndtrplus2->callback((Fl_Callback*)cb_btndtrplus);
+		btndtrplus2->value(progStatus.comm_dtrplus);
 
 		btn2_init_ser_port = new Fl_Button(
-			btndtrptt->x() + incr, btndtrplus->y(), 50, 24, _("Init"));
+			btndtrptt->x() + incr, btndtrplus2->y(), 50, 24, _("Init"));
 		btn2_init_ser_port->callback((Fl_Callback*)cb_init_ser_port);
 
 	grp_catptt->end();
@@ -1504,37 +1539,29 @@ Fl_Group *createPOLLING(int X, int Y, int W, int H, const char *label)
 		xcvr_grp7->box(FL_ENGRAVED_BOX);
 		xcvr_grp7->align(Fl_Align(FL_ALIGN_TOP_LEFT|FL_ALIGN_INSIDE));
 
-		poll_smeter = new Fl_Value_Input(X + 10, Y + 25, 30, 20, _("S-mtr"));
+		poll_smeter = new Fl_Check_Button(X + 10, Y + 25, 30, 20, _("S-mtr"));
 		poll_smeter->tooltip(_("Poll every Nth interval"));
-		poll_smeter->maximum(10);
-		poll_smeter->step(1);
 		poll_smeter->value(1);
 		poll_smeter->callback((Fl_Callback*)cb_poll_smeter);
 		poll_smeter->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_smeter->value(progStatus.poll_smeter);
 
-		poll_pout = new Fl_Value_Input(X + 100, Y + 25, 30, 20, _("Pwr out"));
+		poll_pout = new Fl_Check_Button(X + 100, Y + 25, 30, 20, _("Pwr out"));
 		poll_pout->tooltip(_("Poll every Nth interval"));
-		poll_pout->maximum(10);
-		poll_pout->step(1);
 		poll_pout->value(1);
 		poll_pout->callback((Fl_Callback*)cb_poll_pout);
 		poll_pout->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_pout->value(progStatus.poll_pout);
 
-		poll_swr = new Fl_Value_Input(X + 190, Y + 25, 30, 20, _("SWR"));
+		poll_swr = new Fl_Check_Button(X + 190, Y + 25, 30, 20, _("SWR"));
 		poll_swr->tooltip(_("Poll every Nth interval"));
-		poll_swr->maximum(10);
-		poll_swr->step(1);
 		poll_swr->value(1);
 		poll_swr->callback((Fl_Callback*)cb_poll_swr);
 		poll_swr->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_swr->value(progStatus.poll_swr);
 
-		poll_alc = new Fl_Value_Input(X + 280, Y + 25, 30, 20, _("ALC"));
+		poll_alc = new Fl_Check_Button(X + 280, Y + 25, 30, 20, _("ALC"));
 		poll_alc->tooltip(_("Poll every Nth interval"));
-		poll_alc->maximum(10);
-		poll_alc->step(1);
 		poll_alc->value(1);
 		poll_alc->callback((Fl_Callback*)cb_poll_alc);
 		poll_alc->align(Fl_Align(FL_ALIGN_RIGHT));
@@ -1544,10 +1571,8 @@ Fl_Group *createPOLLING(int X, int Y, int W, int H, const char *label)
 		btnSetMeters->tooltip("Set all meter polls");
 		btnSetMeters->callback((Fl_Callback*)cb_btnSetMeters);
 
-		poll_meters = new Fl_Value_Input(X + 435, Y + 25, 30, 20);
-		poll_meters->tooltip(_("Poll every Nth interval"));
-		poll_meters->maximum(10);
-		poll_meters->step(1);
+		poll_meters = new Fl_Check_Button(X + 435, Y + 25, 30, 20);
+		poll_meters->tooltip(_("Poll all"));
 		poll_meters->value(progStatus.poll_meters);
 		poll_meters->callback((Fl_Callback*)cb_poll_meters);
 		poll_meters->align(Fl_Align(FL_ALIGN_LEFT|FL_ALIGN_INSIDE));
@@ -1558,28 +1583,22 @@ Fl_Group *createPOLLING(int X, int Y, int W, int H, const char *label)
 		xcvr_grp8->box(FL_ENGRAVED_BOX);
 		xcvr_grp8->align(Fl_Align(FL_ALIGN_TOP_LEFT|FL_ALIGN_INSIDE));
 
-		poll_frequency = new Fl_Value_Input(X + 10, Y + 70, 30, 20, _("Freq"));
+		poll_frequency = new Fl_Check_Button(X + 10, Y + 70, 30, 20, _("Freq"));
 		poll_frequency->tooltip(_("Poll xcvr frequency"));
-		poll_frequency->maximum(10);
-		poll_frequency->step(1);
 		poll_frequency->value(1);
 		poll_frequency->callback((Fl_Callback*)cb_poll_frequency);
 		poll_frequency->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_frequency->value(progStatus.poll_frequency);
 
-		poll_mode = new Fl_Value_Input(X + 100, Y + 70, 30, 20, _("Mode"));
+		poll_mode = new Fl_Check_Button(X + 100, Y + 70, 30, 20, _("Mode"));
 		poll_mode->tooltip(_("Poll xcvr mode"));
-		poll_mode->maximum(10);
-		poll_mode->step(1);
 		poll_mode->value(1);
 		poll_mode->callback((Fl_Callback*)cb_poll_mode);
 		poll_mode->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_mode->value(progStatus.poll_mode);
 
-		poll_bandwidth = new Fl_Value_Input(X + 190, Y + 70, 30, 20, _("BW"));
+		poll_bandwidth = new Fl_Check_Button(X + 190, Y + 70, 30, 20, _("BW"));
 		poll_bandwidth->tooltip(_("Poll xcvr bandwidth"));
-		poll_bandwidth->maximum(10);
-		poll_bandwidth->step(1);
 		poll_bandwidth->value(1);
 		poll_bandwidth->callback((Fl_Callback*)cb_poll_bandwidth);
 		poll_bandwidth->align(Fl_Align(FL_ALIGN_RIGHT));
@@ -1589,10 +1608,8 @@ Fl_Group *createPOLLING(int X, int Y, int W, int H, const char *label)
 		btnSetOps->tooltip("Poll all operating values");
 		btnSetOps->callback((Fl_Callback*)cb_btnSetOps);
 
-		poll_ops = new Fl_Value_Input(X + 435, Y + 70, 30, 20);
-		poll_ops->tooltip(_("Poll every Nth interval"));
-		poll_ops->maximum(10);
-		poll_ops->step(1);
+		poll_ops = new Fl_Check_Button(X + 435, Y + 70, 30, 20);
+		poll_ops->tooltip(_("Poll all"));
 		poll_ops->value(progStatus.poll_ops);
 		poll_ops->callback((Fl_Callback*)cb_poll_ops);
 		poll_ops->align(Fl_Align(FL_ALIGN_LEFT|FL_ALIGN_INSIDE));
@@ -1604,130 +1621,98 @@ Fl_Group *createPOLLING(int X, int Y, int W, int H, const char *label)
 		xcvr_grp9->box(FL_ENGRAVED_FRAME);
 		xcvr_grp9->align(Fl_Align(FL_ALIGN_TOP_LEFT|FL_ALIGN_INSIDE));
 
-		poll_volume = new Fl_Value_Input(X + 10, Y + 115, 30, 20, _("Volume"));
+		poll_volume = new Fl_Check_Button(X + 10, Y + 115, 30, 20, _("Volume"));
 		poll_volume->tooltip(_("Volume control"));
-		poll_volume->maximum(10);
-		poll_volume->step(1);
 		poll_volume->callback((Fl_Callback*)cb_poll_volume);
 		poll_volume->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_volume->value(progStatus.poll_volume);
 
-		poll_micgain = new Fl_Value_Input(X + 100, Y + 115, 30, 20, _("Mic"));
+		poll_micgain = new Fl_Check_Button(X + 100, Y + 115, 30, 20, _("Mic"));
 		poll_micgain->tooltip(_("Microphone gain"));
-		poll_micgain->maximum(10);
-		poll_micgain->step(1);
 		poll_micgain->callback((Fl_Callback*)cb_poll_micgain);
 		poll_micgain->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_micgain->value(progStatus.poll_micgain);
 
-		poll_rfgain = new Fl_Value_Input(X + 190, Y + 115, 30, 20, _("RF"));
+		poll_rfgain = new Fl_Check_Button(X + 190, Y + 115, 30, 20, _("RF"));
 		poll_rfgain->tooltip(_("RF gain"));
-		poll_rfgain->maximum(10);
-		poll_rfgain->step(1);
 		poll_rfgain->callback((Fl_Callback*)cb_poll_rfgain);
 		poll_rfgain->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_rfgain->value(progStatus.poll_rfgain);
 
-		poll_power_control = new Fl_Value_Input(X + 280, Y + 115, 30, 20, _("Power"));
+		poll_power_control = new Fl_Check_Button(X + 280, Y + 115, 30, 20, _("Power"));
 		poll_power_control->tooltip(_("Power output"));
-		poll_power_control->maximum(10);
-		poll_power_control->step(1);
 		poll_power_control->callback((Fl_Callback*)cb_poll_power_control);
 		poll_power_control->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_power_control->value(progStatus.poll_power_control);
 
-		poll_ptt = new Fl_Value_Input(X + 370, Y + 115, 30, 20, _("PTT"));
+		poll_ptt = new Fl_Check_Button(X + 370, Y + 115, 30, 20, _("PTT"));
 		poll_ptt->tooltip(_("Push to talk"));
-		poll_ptt->maximum(10);
-		poll_ptt->step(1);
 		poll_ptt->callback((Fl_Callback*)cb_poll_ptt);
 		poll_ptt->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_ptt->value(progStatus.poll_ptt);
 
-		poll_ifshift = new Fl_Value_Input(X + 10, Y + 140, 30, 20, _("IF"));
+		poll_ifshift = new Fl_Check_Button(X + 10, Y + 140, 30, 20, _("IF"));
 		poll_ifshift->tooltip(_("IF shift"));
-		poll_ifshift->maximum(10);
-		poll_ifshift->step(1);
 		poll_ifshift->callback((Fl_Callback*)cb_poll_ifshift);
 		poll_ifshift->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_ifshift->value(progStatus.poll_ifshift);
 
-		poll_notch = new Fl_Value_Input(X + 100, Y + 140, 30, 20, _("Notch"));
+		poll_notch = new Fl_Check_Button(X + 100, Y + 140, 30, 20, _("Notch"));
 		poll_notch->tooltip(_("Manual notch"));
-		poll_notch->maximum(10);
-		poll_notch->step(1);
 		poll_notch->callback((Fl_Callback*)cb_poll_notch);
 		poll_notch->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_notch->value(progStatus.poll_notch);
 
-		poll_auto_notch = new Fl_Value_Input(X + 190, Y + 140, 30, 20, _("Auto"));
+		poll_auto_notch = new Fl_Check_Button(X + 190, Y + 140, 30, 20, _("Auto"));
 		poll_auto_notch->tooltip(_("Auto notch"));
-		poll_auto_notch->maximum(10);
-		poll_auto_notch->step(1);
 		poll_auto_notch->callback((Fl_Callback*)cb_poll_auto_notch);
 		poll_auto_notch->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_auto_notch->value(progStatus.poll_auto_notch);
 
-		poll_tuner = new Fl_Value_Input(X + 280, Y + 140, 30, 20, _("Tuner"));
+		poll_tuner = new Fl_Check_Button(X + 280, Y + 140, 30, 20, _("Tuner"));
 		poll_tuner->tooltip(_("Auto Tuner"));
-		poll_tuner->maximum(10);
-		poll_tuner->step(1);
 		poll_tuner->callback((Fl_Callback*)cb_poll_tuner);
 		poll_tuner->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_tuner->value(progStatus.poll_tuner);
 
-		poll_pre_att = new Fl_Value_Input(X + 10, Y + 165, 30, 20, _("Pre/Att"));
+		poll_pre_att = new Fl_Check_Button(X + 10, Y + 165, 30, 20, _("Pre/Att"));
 		poll_pre_att->tooltip(_("Preamp / Attenuator"));
-		poll_pre_att->maximum(10);
-		poll_pre_att->step(1);
 		poll_pre_att->callback((Fl_Callback*)cb_poll_pre_att);
 		poll_pre_att->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_pre_att->value(progStatus.poll_pre_att);
 
-		poll_squelch = new Fl_Value_Input(X + 100, Y + 165, 30, 20, _("Squelch"));
+		poll_squelch = new Fl_Check_Button(X + 100, Y + 165, 30, 20, _("Squelch"));
 		poll_squelch->tooltip(_("Squelch"));
-		poll_squelch->maximum(10);
-		poll_squelch->step(1);
 		poll_squelch->callback((Fl_Callback*)cb_poll_squelch);
 		poll_squelch->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_squelch->value(progStatus.poll_squelch);
 
-		poll_split = new Fl_Value_Input(X + 190, Y + 165, 30, 20, _("Split"));
+		poll_split = new Fl_Check_Button(X + 190, Y + 165, 30, 20, _("Split"));
 		poll_split->tooltip(_("Split vfo operation"));
-		poll_split->maximum(10);
-		poll_split->step(1);
 		poll_split->callback((Fl_Callback*)cb_poll_split);
 		poll_split->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_split->value(progStatus.poll_split);
 
-		poll_noise = new Fl_Value_Input(X + 10, Y + 190, 30, 20, _("Blanker"));
+		poll_noise = new Fl_Check_Button(X + 10, Y + 190, 30, 20, _("Blanker"));
 		poll_noise->tooltip(_("Noise blanker"));
-		poll_noise->maximum(10);
-		poll_noise->step(1);
 		poll_noise->callback((Fl_Callback*)cb_poll_noise);
 		poll_noise->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_noise->value(progStatus.poll_noise);
 
-		poll_nr = new Fl_Value_Input(X + 100, Y + 190, 30, 20, _("Noise red"));
+		poll_nr = new Fl_Check_Button(X + 100, Y + 190, 30, 20, _("Noise red"));
 		poll_nr->tooltip(_("Noise reduction"));
-		poll_nr->maximum(10);
-		poll_nr->step(1);
 		poll_nr->callback((Fl_Callback*)cb_poll_nr);
 		poll_nr->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_nr->value(progStatus.poll_nr);
 
-		poll_compression = new Fl_Value_Input(X + 190, Y + 190, 30, 20, _("Comp'"));
+		poll_compression = new Fl_Check_Button(X + 190, Y + 190, 30, 20, _("Comp"));
 		poll_compression->tooltip(_("Compression"));
-		poll_compression->maximum(10);
-		poll_compression->step(1);
 		poll_compression->callback((Fl_Callback*)cb_poll_compression);
 		poll_compression->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_compression->value(progStatus.poll_compression);
 
-		poll_break_in = new Fl_Value_Input(X + 280, Y + 165, 30, 20, _("QSK"));
+		poll_break_in = new Fl_Check_Button(X + 280, Y + 165, 30, 20, _("QSK"));
 		poll_break_in->tooltip(_("Break In"));
-		poll_break_in->maximum(10);
-		poll_break_in->step(1);
 		poll_break_in->callback((Fl_Callback*)cb_poll_break_in);
 		poll_break_in->align(Fl_Align(FL_ALIGN_RIGHT));
 		poll_break_in->value(progStatus.poll_break_in);
@@ -1735,11 +1720,9 @@ Fl_Group *createPOLLING(int X, int Y, int W, int H, const char *label)
 		btnSetAdd = new Fl_Button(X + 370, Y + 190, 60, 20, _("Set all"));
 		btnSetAdd->callback((Fl_Callback*)cb_btnSetAdd);
 
-		poll_all = new Fl_Value_Input(X + 435, Y + 190, 30, 20);
-		poll_all->tooltip(_("Poll every Nth interval"));
-		poll_all->maximum(10);
-		poll_all->step(1);
-		poll_all->value(4);
+		poll_all = new Fl_Check_Button(X + 435, Y + 190, 30, 20);
+		poll_all->tooltip(_("Poll all"));
+		poll_all->value(1);
 		poll_all->callback((Fl_Callback*)cb_poll_all);
 		poll_all->align(Fl_Align(FL_ALIGN_LEFT|FL_ALIGN_INSIDE));
 		poll_all->value(progStatus.poll_all);
