@@ -92,7 +92,9 @@ extern Fl_Group *grp_row0a;
 
 extern Fl_Light_Button *btnA;
 extern Fl_Button *btn_K3_swapAB;
+extern Fl_Button *btn_K3_A2B;
 extern Fl_Button *btn_KX3_swapAB;
+extern Fl_Button *btn_KX3_A2B;
 extern Fl_Light_Button *btnB;
 extern Fl_Box *labelMEMORY;
 extern Fl_Button *btnTune;
@@ -127,6 +129,7 @@ extern Fl_Wheel_Value_Slider *sldrMICGAIN;
 extern Fl_Box *bx_sep2a;
 extern Fl_Group *grp_row2b;
 extern Fl_Light_Button *btnIFsh;
+extern Fl_Button *btn_KX3_IFsh;
 extern Fl_Wheel_Value_Slider *sldrIFSHIFT;
 extern Fl_Light_Button *btnNR;
 extern Fl_Wheel_Value_Slider *sldrNR;
@@ -317,7 +320,6 @@ extern Hspinner *cntRIT;
 extern Hspinner *cntXIT;
 extern Hspinner *cntBFO;
 extern Fl_Group *genericAux;
-extern Fl_Box *boxControl;
 extern Fl_Light_Button *btnAuxRTS;
 extern Fl_Light_Button *btnAuxDTR;
 extern Fl_Light_Button *btnDataPort;
@@ -491,8 +493,10 @@ extern Fl_Check_Button *btncatptt;
 extern Fl_Check_Button *btnrtsptt;
 extern Fl_Check_Button *btndtrptt;
 extern Fl_Check_Button *chkrtscts;
-extern Fl_Check_Button *btnrtsplus;
-extern Fl_Check_Button *btndtrplus;
+extern Fl_Check_Button *btnrtsplus1;
+extern Fl_Check_Button *btndtrplus1;
+extern Fl_Check_Button *btnrtsplus2;
+extern Fl_Check_Button *btndtrplus2;
 extern Fl_Int_Input *txtCIV;
 extern Fl_Button *btnCIVdefault;
 extern Fl_Check_Button *btnUSBaudio;
@@ -513,30 +517,30 @@ extern Fl_Group *tabRestore;
 extern Fl_Group *tabTCPIP;
 extern Fl_Group *tabXMLRPC;
 
-extern Fl_Value_Input *poll_smeter;
-extern Fl_Value_Input *poll_pout;
-extern Fl_Value_Input *poll_swr;
-extern Fl_Value_Input *poll_alc;
-extern Fl_Value_Input *poll_frequency;
-extern Fl_Value_Input *poll_mode;
-extern Fl_Value_Input *poll_bandwidth;
-extern Fl_Value_Input *poll_volume;
-extern Fl_Value_Input *poll_micgain;
-extern Fl_Value_Input *poll_rfgain;
-extern Fl_Value_Input *poll_power_control;
-extern Fl_Value_Input *poll_ifshift;
-extern Fl_Value_Input *poll_notch;
-extern Fl_Value_Input *poll_auto_notch;
-extern Fl_Value_Input *poll_pre_att;
-extern Fl_Value_Input *poll_squelch;
-extern Fl_Value_Input *poll_split;
-extern Fl_Value_Input *poll_noise;
-extern Fl_Value_Input *poll_nr;
-extern Fl_Value_Input *poll_compression;
-extern Fl_Value_Input *poll_ptt;
-extern Fl_Value_Input *poll_break_in;
+extern Fl_Check_Button *poll_smeter;
+extern Fl_Check_Button *poll_pout;
+extern Fl_Check_Button *poll_swr;
+extern Fl_Check_Button *poll_alc;
+extern Fl_Check_Button *poll_frequency;
+extern Fl_Check_Button *poll_mode;
+extern Fl_Check_Button *poll_bandwidth;
+extern Fl_Check_Button *poll_volume;
+extern Fl_Check_Button *poll_micgain;
+extern Fl_Check_Button *poll_rfgain;
+extern Fl_Check_Button *poll_power_control;
+extern Fl_Check_Button *poll_ifshift;
+extern Fl_Check_Button *poll_notch;
+extern Fl_Check_Button *poll_auto_notch;
+extern Fl_Check_Button *poll_pre_att;
+extern Fl_Check_Button *poll_squelch;
+extern Fl_Check_Button *poll_split;
+extern Fl_Check_Button *poll_noise;
+extern Fl_Check_Button *poll_nr;
+extern Fl_Check_Button *poll_compression;
+extern Fl_Check_Button *poll_ptt;
+extern Fl_Check_Button *poll_break_in;
 extern Fl_Button *btnClearAddControls;
-extern Fl_Value_Input *poll_all;
+extern Fl_Check_Button *poll_all;
 extern Fl_Button *btnSetAllAdd;
 extern Fl_Group *tabSndCmd;
 
