@@ -101,7 +101,7 @@ struct status {
 	int		poll_split;
 	int		poll_noise;
 	int		poll_nr;
-	int 	poll_vfoAorB;
+//	int 	poll_vfoAorB;
 	int		poll_meters;
 	int		poll_ops;
 	int		poll_compression;
@@ -422,6 +422,7 @@ struct status {
 	bool	debugtrace;
 	bool	xmltrace;
 	bool	rpctrace;
+	bool	serialtrace;
 	bool	start_stop_trace;
 	int		rpc_level;
 
@@ -452,6 +453,9 @@ struct status {
 	int		gpio_on;
 	int		gpio_pulse_width;
 
+// KXPA 100 presence
+	int		kxpa;
+
 // cwio parameters
 	int		cwioWPM;
 	int		cwioKEYLINE;
@@ -463,12 +467,22 @@ struct status {
 	string	cwio_msgs[12];
 	string	cwio_labels[12];
 
+	string	BT;
+	string	AA;
+	string	AS;
+	string	AR;
+	string	KN;
+	string	SK;
+	string	INT;
+	string	HM;
+	string	VE;
+
 	void saveLastState();
 	void loadLastState();
 	bool loadXcvrState(string);
 	void UI_laststate();
 
-	string info();
+	std::string info();
 };
 
 extern status progStatus;
