@@ -32,8 +32,11 @@ extern void xml_trace(int n, ...); // all args of type const char *
 extern void rig_trace(int n, ...); // trace transceiver class methods
 extern void get_trace(int n, ...); // trace get methods
 extern void set_trace(int n, ...); // trace set methods
+extern void ser_trace(int n, ...); // trace serial methods
 extern void rpc_trace(int n, ...); // trace transceiver class methods
 
+extern void make_trace_window();
+
 #define gett(str) get_trace(3, str, cmd.c_str(), replystr.c_str())
 #define sett(str) set_trace(3, str, cmd.c_str(), replystr.c_str())
 
@@ -48,3 +51,11 @@ extern void rpc_trace(int n, ...); // trace transceiver class methods
 	(str2hex(replystr.c_str(), replystr.length())) )
 
 #endif
+
+#define seth() set_trace(2, \
+	(str2hex(cmd.c_str(), cmd.length())), \
+	(str2hex(replystr.c_str(), replystr.length())) )
+
+#define geth() get_trace(2, \
+	(str2hex(cmd.c_str(), cmd.length())), \
+	(str2hex(replystr.c_str(), replystr.length())) )
