@@ -38,6 +38,8 @@ RIG_FT747		rig_FT747;
 RIG_FT757GX2	rig_FT757GX2;
 RIG_FT767		rig_FT767;
 RIG_FT817		rig_FT817;
+RIG_FT817BB		rig_FT817BB;
+RIG_FT818ND		rig_FT818ND;
 RIG_FT847		rig_FT847;
 RIG_FT857D		rig_FT857D;
 RIG_FT890		rig_FT890;
@@ -90,6 +92,7 @@ RIG_K3			rig_K3;
 RIG_KX3			rig_KX3;
 RIG_PCR1000		rig_PCR1000;
 RIG_RAY152		rig_RAY152;
+RIG_TMD710		rig_TMD710;
 RIG_TS140		rig_TS140;
 RIG_TS450S		rig_TS450S;
 RIG_TS480HX		rig_TS480HX;
@@ -127,85 +130,88 @@ rigbase *rigs[] = {
 	&rig_FT757GX2,	// 6
 	&rig_FT767,		// 7
 	&rig_FT817,		// 8
-	&rig_FT847,		// 9
-	&rig_FT857D,	// 10
-	&rig_FT890,		// 11
-	&rig_FT897D,	// 12
-	&rig_FT891,		// 13
-	&rig_FT900,		// 14
-	&rig_FT920,		// 15
-	&rig_FT950,		// 16
-	&rig_FT990,		// 17
-	&rig_FT990A,	// 18
-	&rig_FT991,		// 19
-	&rig_FT991A,	// 20
-	&rig_FT1000,	// 21
-	&rig_FT1000MP,	// 22
-	&rig_FT2000,	// 23
-	&rig_FTdx101D,	// 24
-	&rig_FTdx101MP,	// 25
-	&rig_FTdx1200,	// 26
-	&rig_FTdx3000,	// 27
-	&rig_FT5000,	// 28
-	&rig_FTdx9000,	// 29
-	&rig_IC703,		// 30
-	&rig_IC705,		// 31
-	&rig_IC706MKIIG,// 32
-	&rig_IC718,		// 33
-	&rig_IC728,		// 34
-	&rig_IC735,		// 35
-	&rig_IC746,		// 36
-	&rig_IC746PRO,	// 37
-	&rig_IC756,		// 38
-	&rig_IC756PRO,	// 39
-	&rig_IC756PRO2,	// 40
-	&rig_IC756PRO3,	// 41
-	&rig_IC7000,	// 42
-	&rig_IC7100,	// 43
-	&rig_IC7200,	// 44
-	&rig_IC7300,	// 45
-	&rig_IC7410,	// 46
-	&rig_IC7600,	// 47
-	&rig_IC7610,	// 48
-	&rig_IC7700,	// 49
-	&rig_IC7800,	// 50
-	&rig_IC7851,	// 51
-	&rig_IC9100,	// 52
-	&rig_IC9700,	// 53
-	&rig_IC910H,	// 54
-	&rig_ICF8101,	// 55
-	&rig_K2,		// 56
-	&rig_K3,		// 57
-	&rig_KX3,		// 58
-	&rig_PCR1000,	// 59
-	&rig_RAY152,	// 60
-	&rig_TS140,		// 61
-	&rig_TS450S,	// 62
-	&rig_TS480HX,	// 63
-	&rig_TS480SAT,	// 64
-	&rig_TS570,		// 65
-	&rig_TS590S,	// 66
-	&rig_TS590SG,	// 67
-	&rig_TS790,		// 68
-	&rig_TS850,		// 69
-	&rig_TS870S,	// 70
-	&rig_TS890S,	// 71
-	&rig_TS940S,	// 72
-	&rig_TS950,		// 73
-	&rig_TS990,		// 74
-	&rig_TS2000,	// 75
-	&rig_TT516,		// 76
-	&rig_TT535,		// 77
-	&rig_TT538,		// 78
-	&rig_TT550,		// 79
-	&rig_TT563,		// 80
-	&rig_TT566,		// 81
-	&rig_TT588,		// 82
-	&rig_TT599,		// 83
-	&rig_AOR5K,		// 84
-	&rig_XI5105,	// 85
-	&rig_XIG90,		// 86
-	&rig_PowerSDR,	// 87
+	&rig_FT817BB,	// 9
+	&rig_FT818ND,	// 10
+	&rig_FT847,		// 11
+	&rig_FT857D,	// 12
+	&rig_FT890,		// 13
+	&rig_FT897D,	// 14
+	&rig_FT891,		// 15
+	&rig_FT900,		// 16
+	&rig_FT920,		// 17
+	&rig_FT950,		// 18
+	&rig_FT990,		// 19
+	&rig_FT990A,	// 20
+	&rig_FT991,		// 21
+	&rig_FT991A,	// 22
+	&rig_FT1000,	// 23
+	&rig_FT1000MP,	// 24
+	&rig_FT2000,	// 25
+	&rig_FTdx101D,	// 26
+	&rig_FTdx101MP,	// 27
+	&rig_FTdx1200,	// 28
+	&rig_FTdx3000,	// 29
+	&rig_FT5000,	// 30
+	&rig_FTdx9000,	// 31
+	&rig_IC703,		// 32
+	&rig_IC705,		// 33
+	&rig_IC706MKIIG,// 34
+	&rig_IC718,		// 35
+	&rig_IC728,		// 36
+	&rig_IC735,		// 37
+	&rig_IC746,		// 38
+	&rig_IC746PRO,	// 39
+	&rig_IC756,		// 40
+	&rig_IC756PRO,	// 41
+	&rig_IC756PRO2,	// 42
+	&rig_IC756PRO3,	// 43
+	&rig_IC7000,	// 44
+	&rig_IC7100,	// 45
+	&rig_IC7200,	// 46
+	&rig_IC7300,	// 47
+	&rig_IC7410,	// 48
+	&rig_IC7600,	// 49
+	&rig_IC7610,	// 50
+	&rig_IC7700,	// 51
+	&rig_IC7800,	// 52
+	&rig_IC7851,	// 53
+	&rig_IC9100,	// 54
+	&rig_IC9700,	// 55
+	&rig_IC910H,	// 56
+	&rig_ICF8101,	// 57
+	&rig_K2,		// 58
+	&rig_K3,		// 59
+	&rig_KX3,		// 60
+	&rig_PCR1000,	// 61
+	&rig_RAY152,	// 62
+	&rig_TMD710,	// 63
+	&rig_TS140,		// 64
+	&rig_TS450S,	// 65
+	&rig_TS480HX,	// 66
+	&rig_TS480SAT,	// 67
+	&rig_TS570,		// 68
+	&rig_TS590S,	// 69
+	&rig_TS590SG,	// 70
+	&rig_TS790,		// 71
+	&rig_TS850,		// 72
+	&rig_TS870S,	// 73
+	&rig_TS890S,	// 74
+	&rig_TS940S,	// 75
+	&rig_TS950,		// 76
+	&rig_TS990,		// 77
+	&rig_TS2000,	// 78
+	&rig_TT516,		// 79
+	&rig_TT535,		// 80
+	&rig_TT538,		// 81
+	&rig_TT550,		// 82
+	&rig_TT563,		// 83
+	&rig_TT566,		// 84
+	&rig_TT588,		// 85
+	&rig_TT599,		// 86
+	&rig_AOR5K,		// 87
+	&rig_XI5105,	// 88
+	&rig_XIG90,		// 89
+	&rig_PowerSDR,	// 90
 
 	NULL
 };
