@@ -38,7 +38,6 @@
 #include "rigpanel.h"
 #include "ui.h"
 #include "debug.h"
-#include "IC706MKIIG.h"
 
 string xcvr_name = "NONE";
 
@@ -114,7 +113,7 @@ status progStatus = {
 	1,			// bool	poll_split;
 	1,			// bool	poll_noise;
 	1,			// bool	poll_nr;
-	1,			// int  poll_vfoAorB;
+//	0,			// int  poll_vfoAorB;
 	1,			// poll_meters;
 	1,			// poll_ops;
 	1,			// poll_compression;
@@ -438,6 +437,7 @@ status progStatus = {
 	false,		// bool	debugtrace;
 	false,		// bool	xmltrace;
 	false,		// bool	rpctrace;
+	false,		// bool	serialtrace;
 	false,		// bool	start_stop_trace;
 	0,			// int	rpc_level;
 
@@ -466,7 +466,10 @@ status progStatus = {
 	false,		// bool	gpio_ptt;
 	0,			// int	enable_gpio;
 	0,			// int	gpio_on;
-	0,			//int	gpio_pulse_width;
+	0,			// int	gpio_pulse_width;
+
+// KXPA 100 presence
+	0,			// int kxpa on line = 1
 
 // cwio parameters
 	20,			// int    cwioWPM;
@@ -477,6 +480,21 @@ status progStatus = {
 	0,			// double cwio_comp;
 	"",			// string cwioPORT;
 
+	"","","","","","",
+	"","","","","","",					// string	cwio_msgs[12];
+	"m2","m2","m3","m4","m4","m6",
+	"m7","m8","m9","m10","m11","m12",	// string	cwio_labels[12];
+
+	"=",		// string	BT;
+	"~",		// string	AA;
+	"<",		// string	AS;
+	">",		// string	AR;
+	"%",		// string	KN;
+	"+",		// string	SK;
+	"&",		// string	INT;
+	"{",		// string	HM;
+	"}",		// string	VE;
+
 };
 
 void status::saveLastState()
@@ -924,6 +942,7 @@ void status::saveLastState()
 	spref.set("debugtrace", debugtrace);
 	spref.set("xmltrace", xmltrace);
 	spref.set("rpctrace", rpctrace);
+	spref.set("serialtrace", serialtrace);
 	spref.set("startstoptrace", start_stop_trace);
 	spref.set("rpc_level", rpc_level);
 
@@ -1007,8 +1026,19 @@ void status::saveLastState()
 		spref.set(setbuff, cwio_labels[n].c_str());
 		snprintf(setbuff, sizeof(setbuff), "cwiomessage[%d]", n);
 		spref.set(setbuff, cwio_msgs[n].c_str());
+	
 	}
 
+	spref.set("BT", BT.c_str());
+	spref.set("AA", AA.c_str());
+	spref.set("AS", AS.c_str());
+	spref.set("AR", AR.c_str());
+	spref.set("KN", KN.c_str());
+	spref.set("SK", SK.c_str());
+	spref.set("INT", INT.c_str());
+	spref.set("HM", HM.c_str());
+	spref.set("VE", VE.c_str());
+
 }
 
 bool status::loadXcvrState(string xcvr)
@@ -1552,6 +1582,7 @@ bool status::loadXcvrState(string xcvr)
 		if (spref.get("settrace", i, settrace)) settrace = i;
 		if (spref.get("debugtrace", i, debugtrace)) debugtrace = i;
 		if (spref.get("xmltrace", i, xmltrace)) xmltrace = i;
+		if (spref.get("serialtrace", i, serialtrace)) serialtrace = i;
 		if (spref.get("startstoptrace", i, start_stop_trace)) start_stop_trace = i;
 		if (spref.get("rpctrace", i, rpctrace)) rpctrace = i;
 
@@ -1642,7 +1673,26 @@ bool status::loadXcvrState(string xcvr)
 			cwio_msgs[n] = defbuffer;
 		}
 
-		return true;
+		spref.get("BT", defbuffer, BT.c_str(), 499);
+		BT = defbuffer;
+		spref.get("AA", defbuffer, AA.c_str(), 499);
+		AA = defbuffer;
+		spref.get("AS", defbuffer, AS.c_str(), 499);
+		AS = defbuffer;
+		spref.get("AR", defbuffer, AR.c_str(), 499);
+		AR = defbuffer;
+		spref.get("KN", defbuffer, KN.c_str(), 499);
+		KN = defbuffer;
+		spref.get("SK", defbuffer, SK.c_str(), 499);
+		SK = defbuffer;
+		spref.get("INT", defbuffer, INT.c_str(), 499);
+		INT = defbuffer;
+		spref.get("HM", defbuffer, HM.c_str(), 499);
+		HM = defbuffer;
+		spref.get("VE", defbuffer, VE.c_str(), 499);
+		VE = defbuffer;
+
+		return true; 
 	}
 	return false;
 }
@@ -1818,7 +1868,8 @@ void status::UI_laststate()
 
 string status::info()
 {
-	stringstream info;
+	std::stringstream info;
+	static std::string retinfo;
 
 	info << "status::info()\n============== Prefs File Contents =============\n\n";
 	info << "xcvr_serial_port   : " << xcvr_serial_port << "\n";
@@ -1975,7 +2026,17 @@ string status::info()
 	info << "label 24           : " << label24 << "\n";
 	info << "command 24         : " << command24 << "\n";
 
-	return info.str();
+	info << "BT                 : " << BT << "\n";
+	info << "AA                 : " << AA << "\n";
+	info << "AS                 : " << AS << "\n";
+	info << "AR                 : " << AR << "\n";
+	info << "KN                 : " << KN << "\n";
+	info << "SK                 : " << SK << "\n";
+	info << "INT                : " << INT << "\n";
+	info << "HM                 : " << HM << "\n";
+	info << "VE                 : " << VE << "\n";
+
+	return retinfo = info.str();
 }
 
 static bool strace;
